#include <ArduinoBLE.h>

BLEService ledService("b4bf4c90-a3eb-413f-9698-cfaaa9a428cc");
BLEByteCharacteristic ledCharacteristic("b4bf4c91-a3eb-413f-9698-cfaaa9a428cc", BLERead | BLEWrite);

/** Commands:
 * ------+-----------------------
 * CODE  |   LEDs ON
 * ------+-----------------------
 * 0x00  |   NONE
 * 0x01  |   LED_D0
 * 0x02  |   LED_D1
 * 0x03  |   LED_D0 LED_D1
 * 0x04  |   LED_D2
 * 0x05  |   LED_D0 LED_D2
 * 0x06  |   LED_D1 LED_D2
 * 0x07  |   LED_D0 LED_D1 LED_D2
 * 0x08  |   LED_D3
 * 0x09  |   LED_D0 LED_D3
 * 0x0A  |   LED_D1 LED_D3
 * 0x0B  |   LED_D0 LED_D1 LED_D3
 * 0x0C  |   LED_D2 LED_D3
 * 0x0D  |   LED_D0 LED_D2 LED_D3
 * 0x0E  |   LED_D1 LED_D2 LED_D3
 * 0x0F  |   ALL
 * ------+-----------------------
 */

void setup()
{
    Serial.begin(9600);

    // Init the BLE service.
    if (BLE.begin() == 0)
    {
        while (1)
        {
        }
    }

    // Set local name and service UUID.
    BLE.setLocalName("Finder Opta");
    BLE.setAdvertisedService(ledService);

    // Add service and characeristic.
    ledService.addCharacteristic(ledCharacteristic);
    BLE.addService(ledService);

    // Set initial value.
    ledCharacteristic.writeValue(0x00);

    // Start advertising.
    BLE.advertise();
}

void loop()
{
    // Check if any central is available.
    BLEDevice central = BLE.central();
    if (central)
    {
        Serial.println("Central connected.");
        while (central.connected())
        {
            // If central wrote to characeristic.
            if (ledCharacteristic.written())
            {
                uint8_t state = ledCharacteristic.value();
                digitalWrite(LED_D0, state & 0x01);
                digitalWrite(LED_D1, (state & 0x02) >> 1);
                digitalWrite(LED_D2, (state & 0x04) >> 2);
                digitalWrite(LED_D3, (state & 0x08) >> 3);
            }
        }
        Serial.println("Central disconnected.");
    }
}
